@@ -2,7 +2,7 @@
 
 """
 GNU General Public License v3.0 (GPL v3)
-Copyright (c) 2020-2020 WardPearce
+Copyright (c) 2020-2021 WardPearce
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
 to deal in the Software without restriction, including without limitation
@@ -61,17 +61,14 @@ from .routes.errors import auth_error
 
 from .background_tasks import TASKS_TO_SPAWN
 
-from .misc import (
-    cache_community_types,
-    create_product_and_set
-)
+from .misc import cache_community_types
 
 from .key_loader import KeyLoader
 
 from .constants import MAP_IMAGES, COMMUNITY_TYPES
 
 
-__version__ = "0.1.5"
+__version__ = "0.2.0"
 __url__ = "https://github.com/WardPearce/SQLMatches"
 __description__ = "SQLMatches, match & demos recorder."
 __author__ = "WardPearce"
@@ -97,13 +94,12 @@ class SQLMatches(Starlette):
                  upload_delay: float = 0.00001,
                  free_upload_size: float = 30.0,
                  max_upload_size: float = 100.0,
-                 cost_per_mb: float = 0.15,
                  timestamp_format: str = "%m/%d/%Y-%H:%M:%S",
                  community_types: List[str] = COMMUNITY_TYPES,
                  webhook_timeout: float = 3.0,
                  match_max_length: timedelta = timedelta(hours=3),
-                 payment_expires: timedelta = timedelta(days=31),
                  demo_expires: timedelta = timedelta(weeks=20),
+                 subscription_length: timedelta = timedelta(days=31),
                  clear_cache: bool = True,
                  **kwargs) -> None:
         """SQLMatches API.
@@ -126,8 +122,6 @@ class SQLMatches(Starlette):
             by default 50.0
         max_upload_size : float, optional
             by default 100.0
-        cost_per_mb : float, optional
-            by default 0.15
         timestamp_format : str, optional
             by default "%m/%d/%Y-%H:%M:%S"
         community_types : List[str], optional
@@ -136,8 +130,10 @@ class SQLMatches(Starlette):
             by default 3.0
         match_max_length : timedelta, optional
             by default timedelta(hours=3)
-        payment_expires : timedelta, optional
-            by default timedelta(days=31)
+        clear_cache : bool, optional
+            by default True
+        demo_expires : timedelta, optional
+            by default timedelta(weeks=20)
         """
 
         startup_tasks = [self._startup]
@@ -185,7 +181,6 @@ class SQLMatches(Starlette):
         Config.upload_delay = upload_delay
         Config.free_upload_size = free_upload_size
         Config.max_upload_size = max_upload_size
-        Config.cost_per_mb = cost_per_mb
         Config.timestamp_format = timestamp_format
         Config.root_steam_id_hashed = bcrypt.hashpw(
             root_steam_id.encode(), bcrypt.gensalt()
@@ -195,16 +190,14 @@ class SQLMatches(Starlette):
         )
         Config.webhook_timeout = webhook_timeout
         Config.match_max_length = match_max_length
-        Config.payment_expires = payment_expires
         Config.system_email = system_email
         Config.frontend_url = frontend_url
-        Config.currency = stripe_settings.currency
-        Config.receipt_url_base = stripe_settings.receipt_url_base
         Config.demo_expires = demo_expires
+        Config.price_id = stripe_settings.price_id
+        Config.subscription_length = subscription_length
 
         self.community_types = community_types
         self.clear_cache = clear_cache
-        self.product_name = stripe_settings.product_name
 
         database_url = "://{}:{}@{}:{}/{}?charset=utf8mb4".format(
             database_settings.username,
@@ -317,7 +310,6 @@ class SQLMatches(Starlette):
             await self.background_tasks.spawn(to_spawn())
 
         await cache_community_types(self.community_types)
-        await create_product_and_set(self.product_name)
 
     async def _shutdown(self) -> None:
         """Closes any underlying sessions.
